@@ -16,14 +16,14 @@
 #include <QDesktopServices>
 #endif
 
-Database* databaseInstance = 0;
+Database* Database::self = 0;
 
 Database::Database(QObject *parent) :
     QObject(parent),
     m_database(QSqlDatabase::addDatabase("QSQLITE"))
 {
-    if (!databaseInstance) {
-        databaseInstance = this;
+    if (!self) {
+        self = this;
     }
 #if (defined (Q_WS_MAEMO_5)) || (defined (MEEGO_EDITION_HARMATTAN))
     QDir dir;
@@ -44,13 +44,12 @@ Database::Database(QObject *parent) :
 }
 
 Database* Database::instance() {
-    return databaseInstance;
+    return !self ? new Database : self;
 }
 
 void Database::initialize() {
     if (m_database.open()) {
-        m_database.exec("DROP TABLE IF EXISTS downloads");
-        m_database.exec("CREATE TABLE IF NOT EXISTS storedDownloads (id TEXT UNIQUE, videoId TEXT, title TEXT, thumbnailUrl TEXT, downloadPath TEXT, tempFileName TEXT, fileName TEXT, service INTEGER, videoFormat INTEGER, priority INTEGER, saveAsAudio INTEGER, size TEXT)");
+        m_database.exec("DROP TABLE IF EXISTS storedDownloads");
         m_database.exec("CREATE TABLE IF NOT EXISTS youtubeAccounts (name TEXT UNIQUE, username TEXT, token TEXT, refresh TEXT, active INTEGER)");
         m_database.exec("CREATE TABLE IF NOT EXISTS dailymotionAccounts (name TEXT UNIQUE, username TEXT, token TEXT, refresh TEXT, active INTEGER)");
         m_database.exec("CREATE TABLE IF NOT EXISTS vimeoAccounts (name TEXT UNIQUE, username TEXT, token TEXT, secret TEXT, active INTEGER)");
@@ -443,104 +442,3 @@ void Database::restoreTwitterAccount() {
         }
     }
 }
-
-bool Database::storeDownload(QSharedPointer<TransferItem> transfer) {
-    if ((m_database.isOpen()) || (m_database.open())) {
-        QSqlQuery query;
-        query.prepare("INSERT OR IGNORE INTO storedDownloads VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
-        query.addBindValue(transfer.data()->id());
-        query.addBindValue(transfer.data()->videoId());
-        query.addBindValue(transfer.data()->title());
-        query.addBindValue(transfer.data()->thumbnailUrl());
-        query.addBindValue(transfer.data()->downloadPath());
-        query.addBindValue(transfer.data()->tempFileName());
-        query.addBindValue(transfer.data()->fileName());
-        query.addBindValue(Services::VideoService(transfer.data()->service()));
-        query.addBindValue(Videos::VideoFormat(transfer.data()->videoFormat()));
-#ifdef MEEGO_EDITION_HARMATTAN
-        query.addBindValue(Transfers::TransferPriority(Transfers::NormalPriority));
-#else
-        query.addBindValue(Transfers::TransferPriority(transfer.data()->priority()));
-#endif
-        query.addBindValue(transfer.data()->saveAsAudio());
-        query.addBindValue(0);
-        bool success = query.exec();
-        m_database.close();
-
-        return success;
-    }
-
-    return false;
-}
-
-bool Database::removeStoredDownload(const QString &id) {
-    if ((m_database.isOpen()) || (m_database.open())) {
-        QSqlQuery query;
-        query.prepare("DELETE FROM storedDownloads WHERE id = ?");
-        query.addBindValue(id);
-        bool success = query.exec();
-        m_database.close();
-
-        return success;
-    }
-
-    return false;
-}
-
-bool Database::updateStoredDownload(const QString &id, const QString &key, const QVariant &value) {
-    if ((m_database.isOpen()) || (m_database.open())) {
-        QSqlQuery query;
-        query.prepare(QString("UPDATE storedDownloads SET %1 = ? WHERE id = ?").arg(key));
-        query.addBindValue(value);
-        query.addBindValue(id);
-        bool success = query.exec();
-        m_database.close();
-
-        return success;
-    }
-
-    return false;
-}
-
-QList< QSharedPointer<TransferItem> > Database::getStoredDownloads() {
-    QList< QSharedPointer<TransferItem> > transfers;
-
-    if ((m_database.isOpen()) || (m_database.open())) {
-        QSqlQuery query;
-        QSqlRecord record;
-        query.exec("SELECT * FROM storedDownloads");
-        record = query.record();
-
-        if (record.count() > 0) {
-            while (query.next()) {
-                QSharedPointer<TransferItem> transfer(new TransferItem);
-                transfer.data()->setId(query.value(0).toString());
-                transfer.data()->setVideoId(query.value(1).toString());
-                transfer.data()->setTitle(query.value(2).toString());
-                transfer.data()->setThumbnailUrl(query.value(3).toUrl());
-                transfer.data()->setDownloadPath(query.value(4).toString());
-                transfer.data()->setTempFileName(query.value(5).toString());
-                transfer.data()->setFileName(query.value(6).toString());
-                transfer.data()->setService(static_cast<Services::VideoService>(query.value(7).toInt()));
-                transfer.data()->setVideoFormat(static_cast<Videos::VideoFormat>(query.value(8).toInt()));
-#ifndef MEEGO_EDITION_HARMATTAN
-                transfer.data()->setPriority(static_cast<Transfers::TransferPriority>(query.value(9).toInt()));
-#endif
-                transfer.data()->setSaveAsAudio(query.value(10).toBool());
-                transfer.data()->setSize(query.value(11).toLongLong());
-
-                QFileInfo file(transfer.data()->downloadPath() + transfer.data()->tempFileName());
-
-                if ((file.size() > 0) && (transfer.data()->size() > 0)) {
-                    transfer.data()->setProgress(file.size() * 100 / transfer.data()->size());
-                }
-
-                transfers.append(transfer);
-            }
-        }
-
-        m_database.close();
-    }
-
-    return transfers;
-}
