@@ -74,6 +74,10 @@ class Settings : public QSettings
                READ enableDailymotion480Playback
                WRITE setEnableDailymotion480Playback
                NOTIFY enableDailymotion480PlaybackChanged)
+    Q_PROPERTY(bool enableDailymotion384Playback
+               READ enableDailymotion384Playback
+               WRITE setEnableDailymotion384Playback
+               NOTIFY enableDailymotion384PlaybackChanged)
     Q_PROPERTY(bool enableDailymotion1080Download
                READ enableDailymotion1080Download
                WRITE setEnableDailymotion1080Download
@@ -86,6 +90,10 @@ class Settings : public QSettings
                READ enableDailymotion480Download
                WRITE setEnableDailymotion480Download
                NOTIFY enableDailymotion480DownloadChanged)
+    Q_PROPERTY(bool enableDailymotion384Download
+               READ enableDailymotion384Download
+               WRITE setEnableDailymotion384Download
+               NOTIFY enableDailymotion384DownloadChanged)
     Q_PROPERTY(bool enableVimeo720Playback
                READ enableVimeo720Playback
                WRITE setEnableVimeo720Playback
@@ -114,6 +122,14 @@ class Settings : public QSettings
                READ maximumConcurrentTransfers
                WRITE setMaximumConcurrentTransfers
                NOTIFY maximumConcurrentTransfersChanged)
+    Q_PROPERTY(int maximumConnectionsPerTransfer
+               READ maximumConnectionsPerTransfer
+               WRITE setMaximumConnectionsPerTransfer
+               NOTIFY maximumConnectionsPerTransferChanged)
+    Q_PROPERTY(bool downloadSubtitles
+               READ downloadSubtitles
+               WRITE setDownloadSubtitles
+               NOTIFY downloadSubtitlesChanged)
     Q_PROPERTY(bool safeSearch
                READ safeSearch
                WRITE setSafeSearch
@@ -166,6 +182,10 @@ class Settings : public QSettings
                READ showSearchLanguage
                WRITE setShowSearchLanguage
                NOTIFY showSearchLanguageChanged)
+    Q_PROPERTY(QString subtitlesLanguage
+               READ subtitlesLanguage
+               WRITE setSubtitlesLanguage
+               NOTIFY subtitlesLanguageChanged)
 #if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
     Q_PROPERTY(QString theme
                READ theme
@@ -196,6 +216,12 @@ class Settings : public QSettings
                READ screenOrientation
                WRITE setScreenOrientation
                NOTIFY screenOrientationChanged)
+#if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
+    Q_PROPERTY(bool fullscreen
+               READ fullscreen
+               WRITE setFullscreen
+               NOTIFY fullscreenChanged)
+#endif
     Q_PROPERTY(QString uploadAttribute
                READ uploadAttribute
                WRITE setUploadAttribute
@@ -286,16 +312,20 @@ public:
     inline bool enableDailymotion1080Playback() const { return m_dailymotionPlaybackFormats.contains(Videos::SuperHD); }
     inline bool enableDailymotion720Playback() const { return m_dailymotionPlaybackFormats.contains(Videos::HD); }
     inline bool enableDailymotion480Playback() const { return m_dailymotionPlaybackFormats.contains(Videos::HQ); }
+    inline bool enableDailymotion384Playback() const { return m_dailymotionPlaybackFormats.contains(Videos::Normal); }
     inline bool enableDailymotion1080Download() const { return m_dailymotionDownloadFormats.contains(Videos::SuperHD); }
     inline bool enableDailymotion720Download() const { return m_dailymotionDownloadFormats.contains(Videos::HD); }
     inline bool enableDailymotion480Download() const { return m_dailymotionDownloadFormats.contains(Videos::HQ); }
+    inline bool enableDailymotion384Download() const { return m_dailymotionDownloadFormats.contains(Videos::Normal); }
     inline bool enableVimeo720Playback() const { return m_vimeoPlaybackFormats.contains(Videos::HD); }
     inline bool enableVimeo360Playback() const { return m_vimeoPlaybackFormats.contains(Videos::Normal); }
     inline bool enableVimeo720Download() const { return m_vimeoDownloadFormats.contains(Videos::HD); }
     inline bool enableVimeo360Download() const { return m_vimeoDownloadFormats.contains(Videos::Normal); }
+    inline QString downloadPath() const { return m_path; }
     inline bool startTransfersAutomatically() const { return m_autoTransfers; }
     inline int maximumConcurrentTransfers() const { return m_maxConcurrentTransfers; }
-    inline QString downloadPath() const { return m_path; }
+    inline int maximumConnectionsPerTransfer() const { return m_maxConnectionsPerTransfer; }
+    inline bool downloadSubtitles() const { return m_downloadSubtitles; }
     inline bool safeSearch() { return m_safeSearch; }
     inline Services::VideoService searchSite() const { return this->showSearchSite() ? m_searchSite : Services::YouTube; }
     inline bool showSearchSite() const { return m_showSearchSite; }
@@ -309,6 +339,7 @@ public:
     inline bool showSearchType() const { return m_showSearchType; }
     inline QString languageFilter() const { return m_languageFilter; }
     inline bool showSearchLanguage() const { return m_showSearchLanguage; }
+    inline QString subtitlesLanguage() const { return m_subtitlesLanguage; }
 #if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
     inline QString theme() const { return m_theme; }
     inline QString activeColor() const { return m_activeColor; }
@@ -324,6 +355,9 @@ public:
 #endif
 #endif
     inline ScreenOrientation::Orientation screenOrientation() const { return m_orientation; }
+#if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
+    inline bool fullscreen() const { return m_fullscreen; }
+#endif
     inline bool monitorClipboard() const { return m_monitorClipboard; }
     inline NetworkProxyType::ProxyType networkProxyType() const { return m_proxyType; }
     QString networkProxyTypeString() const;
@@ -360,16 +394,20 @@ public slots:
     void setEnableDailymotion1080Playback(bool enable);
     void setEnableDailymotion720Playback(bool enable);
     void setEnableDailymotion480Playback(bool enable);
+    void setEnableDailymotion384Playback(bool enable);
     void setEnableDailymotion1080Download(bool enable);
     void setEnableDailymotion720Download(bool enable);
     void setEnableDailymotion480Download(bool enable);
+    void setEnableDailymotion384Download(bool enable);
     void setEnableVimeo720Playback(bool enable);
     void setEnableVimeo360Playback(bool enable);
     void setEnableVimeo720Download(bool enable);
     void setEnableVimeo360Download(bool enable);
+    void setDownloadPath(const QString &path);
     void setStartTransfersAutomatically(bool automatic);
     void setMaximumConcurrentTransfers(int maximum);
-    void setDownloadPath(const QString &path);
+    void setMaximumConnectionsPerTransfer(int maximum);
+    void setDownloadSubtitles(bool download);
     void setSafeSearch(bool safe);
     void setSearchSite(Services::VideoService site);
     void setShowSearchSite(bool show);
@@ -383,6 +421,7 @@ public slots:
     void setShowSearchType(bool show);
     void setLanguageFilter(const QString &language);
     void setShowSearchLanguage(bool show);
+    void setSubtitlesLanguage(const QString &language);
 #if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
     void setTheme(const QString &theme);
 #ifdef MEEGO_EDITION_HARMATTAN
@@ -400,6 +439,9 @@ public slots:
 #endif
 #endif
     void setScreenOrientation(ScreenOrientation::Orientation orientation);
+#if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
+    void setFullscreen(bool fullscreen);
+#endif
     void setMonitorClipboard(bool monitor);
     void setNetworkProxyType(NetworkProxyType::ProxyType proxyType);
     void setNetworkProxyHostName(const QString &hostName);
@@ -443,9 +485,11 @@ signals:
     void enableDailymotion1080PlaybackChanged();
     void enableDailymotion720PlaybackChanged();
     void enableDailymotion480PlaybackChanged();
+    void enableDailymotion384PlaybackChanged();
     void enableDailymotion1080DownloadChanged();
     void enableDailymotion720DownloadChanged();
     void enableDailymotion480DownloadChanged();
+    void enableDailymotion384DownloadChanged();
     void enableVimeo720PlaybackChanged();
     void enableVimeo360PlaybackChanged();
     void enableVimeo720DownloadChanged();
@@ -456,9 +500,11 @@ signals:
     void dailymotionDownloadFormatsChanged(const QSet<int> &formats);
     void vimeoPlaybackFormatsChanged(const QSet<int> &formats);
     void vimeoDownloadFormatsChanged(const QSet<int> &formats);
+    void downloadPathChanged(const QString &path);
     void startTransfersAutomaticallyChanged(bool automatic);
     void maximumConcurrentTransfersChanged(int oldMaximum, int newMaximum);
-    void downloadPathChanged(const QString &path);
+    void maximumConnectionsPerTransferChanged(int oldMaximum, int newMaximum);
+    void downloadSubtitlesChanged(bool download);
     void safeSearchChanged(bool safe);
     void searchSiteChanged(Services::VideoService service);
     void showSearchSiteChanged(bool show);
@@ -472,6 +518,7 @@ signals:
     void showSearchTypeChanged(bool show);
     void languageFilterChanged(const QString &language);
     void showSearchLanguageChanged(bool show);
+    void subtitlesLanguageChanged(const QString &language);
 #if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
     void themeChanged(const QString &themeString);
 #ifdef MEEGO_EDITION_HARMATTAN
@@ -490,6 +537,7 @@ signals:
 #endif
 #endif
     void screenOrientationChanged(ScreenOrientation::Orientation orientation);
+    void fullscreenChanged(bool fullscreen);
     void monitorClipboardChanged(bool monitor);
     void networkProxyTypeChanged(NetworkProxyType::ProxyType proxyType);
     void networkProxyTypeStringChanged(const QString &proxyTypeString);
@@ -505,15 +553,19 @@ signals:
 #endif
 
 private:
+    static Settings *self;
+
     QSet<int> m_youtubePlaybackFormats;
     QSet<int> m_youtubeDownloadFormats;
     QSet<int> m_dailymotionPlaybackFormats;
     QSet<int> m_dailymotionDownloadFormats;
     QSet<int> m_vimeoPlaybackFormats;
     QSet<int> m_vimeoDownloadFormats;
+    QString m_path;
     bool m_autoTransfers;
     int m_maxConcurrentTransfers;
-    QString m_path;
+    int m_maxConnectionsPerTransfer;
+    bool m_downloadSubtitles;
     bool m_safeSearch;
     Services::VideoService m_searchSite;
     bool m_showSearchSite;
@@ -527,6 +579,7 @@ private:
     bool m_showSearchType;
     QString m_languageFilter;
     bool m_showSearchLanguage;
+    QString m_subtitlesLanguage;
 #if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
     QString m_theme;
     QString m_activeColor;
@@ -542,6 +595,9 @@ private:
 #endif
 #endif
     ScreenOrientation::Orientation m_orientation;
+#if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
+    bool m_fullscreen;
+#endif
     bool m_monitorClipboard;
     NetworkProxyType::ProxyType m_proxyType;
     QString m_proxyTypeString;
