@@ -1,7 +1,6 @@
 #include "thumbnailcache.h"
 #include "thumbnaildownloader.h"
 #include <QThread>
-#include <QCache>
 #include <QImage>
 #include <QUrl>
 #include <QNetworkReply>
@@ -40,18 +39,18 @@ public:
     const QImage image;
 };
 
-ThumbnailCache* cacheInstance = 0;
-QThread* cacheThread = 0;
-QCache<QUrl, Thumbnail> thumbnails;
+ThumbnailCache* ThumbnailCache::self = 0;
+QThread* ThumbnailCache::cacheThread = 0;
+QCache<QUrl, Thumbnail> ThumbnailCache::thumbnails;
 
 ThumbnailCache::ThumbnailCache(QObject *parent) :
     QObject(parent)
 {
-    if (!cacheInstance) {
-        cacheInstance = this;
+    if (!self) {
+        self = this;
         cacheThread = new QThread(this);
         cacheThread->start();
-        this->connect(cacheInstance, SIGNAL(destroyed()), cacheThread, SLOT(quit()));
+        this->connect(this, SIGNAL(destroyed()), cacheThread, SLOT(quit()));
     }
 
     this->moveToThread(cacheThread);
@@ -65,7 +64,7 @@ ThumbnailCache::ThumbnailCache(QObject *parent) :
 ThumbnailCache::~ThumbnailCache() {}
 
 ThumbnailCache* ThumbnailCache::instance() {
-    return cacheInstance;
+    return !self ? new ThumbnailCache : self;
 }
 
 QImage ThumbnailCache::thumbnail(const QUrl &url, const QSize &scale) {
