@@ -36,6 +36,9 @@ public:
 public:
     explicit VimeoUserAlbumListModel(QObject *parent = 0);
     ~VimeoUserAlbumListModel();
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
@@ -55,10 +58,11 @@ private slots:
 signals:
     void countChanged(int count);
 
-#ifndef QML_USER_INTERFACE
 private:
+#ifndef QML_USER_INTERFACE
     ThumbnailCache *m_cache;
 #endif
+    QHash<int, QByteArray> m_roleNames;
 };
 
 #endif // VIMEOUSERALBUMLISTMODEL_H
