@@ -1,12 +1,11 @@
 #include "facebookauthdialog.h"
-#include "../base/session.h"
+#include "../base/sharing.h"
 #include "webview.h"
 #include <QProgressBar>
 #include <QGridLayout>
 
-FacebookAuthDialog::FacebookAuthDialog(Session *session, QWidget *parent) :
+FacebookAuthDialog::FacebookAuthDialog(QWidget *parent) :
     AbstractDialog(parent),
-    m_session(session),
     m_webView(new WebView(this)),
     m_progressBar(new QProgressBar(this)),
     m_grid(new QGridLayout(this))
@@ -16,7 +15,7 @@ FacebookAuthDialog::FacebookAuthDialog(Session *session, QWidget *parent) :
     m_grid->addWidget(m_webView, 0, 0);
     m_grid->addWidget(m_progressBar, 1, 0);
 
-    m_webView->setUrl(m_session->sharing()->facebookAuthUrl());
+    m_webView->setUrl(Sharing::instance()->facebookAuthUrl());
     m_webView->enableSelectionSuppressor();
     m_progressBar->setTextVisible(false);
 
@@ -24,6 +23,7 @@ FacebookAuthDialog::FacebookAuthDialog(Session *session, QWidget *parent) :
     this->connect(m_webView, SIGNAL(loadProgress(int)), m_progressBar, SLOT(setValue(int)));
     this->connect(m_webView, SIGNAL(loadStarted()), m_progressBar, SLOT(show()));
     this->connect(m_webView, SIGNAL(loadFinished(bool)), m_progressBar, SLOT(hide()));
+    this->connect(this, SIGNAL(rejected()), Sharing::instance(), SLOT(cancelFacebookSignIn()));
 
     this->onOrientationChanged();
 }
@@ -32,7 +32,7 @@ void FacebookAuthDialog::checkUrlForToken(const QUrl &url) {
     QString urlString = url.toString();
 
     if ((urlString.startsWith("http://www.facebook.com/connect/login_success.html")) || (urlString.startsWith("https://www.facebook.com/connect/login_success.html"))) {
-        m_session->sharing()->signInToFacebook(url);
+        Sharing::instance()->signInToFacebook(url);
         this->accept();
     }
 }
