@@ -3,7 +3,6 @@
 
 #include "abstractdialog.h"
 
-class Session;
 class WebView;
 class QProgressBar;
 class QGridLayout;
@@ -13,7 +12,7 @@ class FacebookAuthDialog : public AbstractDialog
 {
     Q_OBJECT
 public:
-    explicit FacebookAuthDialog(Session *session, QWidget *parent = 0);
+    explicit FacebookAuthDialog(QWidget *parent = 0);
 
 private:
     inline void setLandscapeLayout() { this->setFixedHeight(340); }
@@ -23,7 +22,6 @@ private slots:
     void checkUrlForToken(const QUrl &url);
         
 private:
-    Session *m_session;
     WebView *m_webView;
     QProgressBar *m_progressBar;
     QGridLayout *m_grid;
