@@ -53,7 +53,7 @@ void LanguageSelector::hideUnavailableLanguages() {
     for (int i = 0; i < m_model->rowCount(); i++) {
         QString lang = m_model->value(i).toString();
 
-        if (!availableLanguages.contains(QString("cutetube_%1.qm").arg(lang))) {
+        if (!availableLanguages.contains(lang + ".qm")) {
             rowsToRemove.prepend(i);
         }
         else {
