@@ -2,9 +2,11 @@
 #define TRANSFERDETAILSDIALOG_H
 
 #include "abstractdialog.h"
-#include "transferitem.h"
+#include "../base/transferitem.h"
 
 class TransferPrioritySelector;
+class ConnectionsSelector;
+class SubtitlesSelector;
 class QLabel;
 class QLineEdit;
 class QGridLayout;
@@ -22,15 +24,13 @@ private:
     void setPortraitLayout();
 
 private slots:
-    void onTransferStatusChanged(Transfers::TransferStatus status);
-    void onTransferStatusInfoChanged(const QString &info);
+    void onTransferStatusChanged(Transfers::Status status);
     void onTransferSizeChanged(qint64 size);
     void onTransferProgressChanged(int progress);
     void onTransferSpeedChanged(int speed);
     void onFileNameTextChanged(const QString &text);
     void setTransferFileName();
     void onPauseResumeClicked();
-    void cancelTransfer();
 
 private:
     QSharedPointer<TransferItem> m_transfer;
@@ -40,11 +40,13 @@ private:
     QLabel *m_progressHeader;
     QLabel *m_statusLabel;
     QLabel *m_statusIcon;
-    QLabel *m_infoLabel;
     QLabel *m_sizeLabel;
     QLabel *m_progressLabel;
     QLabel *m_speedLabel;
+    ConnectionsSelector *m_connectionsSelector;
     TransferPrioritySelector *m_prioritySelector;
+    SubtitlesSelector *m_subtitlesSelector;
+    QCheckBox *m_subtitlesCheckbox;
     QCheckBox *m_audioCheckbox;
     QLineEdit *m_nameEdit;
     QPushButton *m_nameButton;
