@@ -13,12 +13,12 @@ TransferPrioritySelector::TransferPrioritySelector(const QString &text, QWidget
     this->connect(m_selector, SIGNAL(selected(QString)), this, SLOT(onSelected()));
 }
 
-void TransferPrioritySelector::setValue(Transfers::TransferPriority value) {
+void TransferPrioritySelector::setValue(Transfers::Priority value) {
     bool found = false;
     int i = 0;
 
     while ((!found) && (i < m_model->rowCount())) {
-        found = static_cast<Transfers::TransferPriority>(m_model->value(i).toInt()) == value;
+        found = static_cast<Transfers::Priority>(m_model->value(i).toInt()) == value;
 
         if (found) {
             m_selector->setCurrentIndex(i);
@@ -32,8 +32,8 @@ void TransferPrioritySelector::setValue(Transfers::TransferPriority value) {
     }
 }
 
-Transfers::TransferPriority TransferPrioritySelector::currentValue() {
-    return static_cast<Transfers::TransferPriority>(m_model->value(m_selector->currentIndex()).toInt());
+Transfers::Priority TransferPrioritySelector::currentValue() {
+    return static_cast<Transfers::Priority>(m_model->value(m_selector->currentIndex()).toInt());
 }
 
 void TransferPrioritySelector::onSelected() {
